@@ -3,6 +3,7 @@
 #include "../MessageParser.hpp"
 #include "../../../helpers/Env.hpp"
 
+#include <cstring>
 #include <stdexcept>
 #include <hyprwire/core/types/MessageMagic.hpp>
 
@@ -18,12 +19,15 @@ CNewObjectMessage::CNewObjectMessage(const std::vector<uint8_t>& data, size_t of
         if (data.at(offset + 1) != HW_MESSAGE_MAGIC_TYPE_UINT)
             return;
 
-        m_id = *rc<const uint32_t*>(&data.at(offset + 2));
+        if ((data.size() - offset - 2) < sizeof(m_seq))
+            return;
+
+        std::memcpy(&m_id, &data.at(offset + 2), sizeof(m_id));
 
         if (data.at(offset + 6) != HW_MESSAGE_MAGIC_TYPE_UINT)
             return;
 
-        m_seq = *rc<const uint32_t*>(&data.at(offset + 7));
+        std::memcpy(&m_seq, &data.at(offset + 7), sizeof(m_seq));
 
         if (data.at(offset + 11) != HW_MESSAGE_MAGIC_END)
             return;
@@ -43,6 +47,6 @@ CNewObjectMessage::CNewObjectMessage(uint32_t seq, uint32_t id) {
         HW_MESSAGE_TYPE_NEW_OBJECT, HW_MESSAGE_MAGIC_TYPE_UINT, 0, 0, 0, 0, HW_MESSAGE_MAGIC_TYPE_UINT, 0, 0, 0, 0, HW_MESSAGE_MAGIC_END,
     };
 
-    *rc<uint32_t*>(&m_data[2]) = seq;
-    *rc<uint32_t*>(&m_data[7]) = seq;
+    std::memcpy(&m_data[2], &id, sizeof(id));
+    std::memcpy(&m_data[7], &seq, sizeof(seq));
 }
